@@ -540,9 +540,13 @@
         <translation>Etterbehandling av</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1527"/>
         <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
-        <translation>Feil ved skriving til fil: %1. Undersøk om det er nok ledig plass på disken.</translation>
+        <translation type="vanished">Feil ved skriving til fil: %1. Undersøk om det er nok ledig plass på disken.</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1527"/>
+        <source>There was an error downloading or writing the file: %1. Please check your internet connection and free space on your drive</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1592"/>
