@@ -540,9 +540,13 @@
         <translation>Pós-processando para </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1527"/>
         <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
-        <translation>Houve um erro ao gravar o ficheiro: %1. Verificar se há espaço livre suficiente no disco</translation>
+        <translation type="vanished">Houve um erro ao gravar o ficheiro: %1. Verificar se há espaço livre suficiente no disco</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="1527"/>
+        <source>There was an error downloading or writing the file: %1. Please check your internet connection and free space on your drive</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1592"/>
